@@ -227,7 +227,7 @@ post '/update' => sub ($c) {
   }
   my $model = trim $v->param('model') if $v->param('model');
   my $name  = trim $v->param('name')  if $v->param('name');
-  my $value = trim $v->param('value') if $v->param('value');
+  my $value = trim $v->param('value') if defined $v->param('value');
   my $synth = Synth::Config->new(model => $model);
   # get a specs config file for the synth model
   my $set_file = SETTINGS . $synth->model . '.dat';
@@ -391,7 +391,7 @@ __DATA__
   <input type="hidden" name="model" value="<%= $model %>">
   <input type="hidden" name="groups" value="<%= $groups %>">
 %   for my $g (@$group_list) {
-  <input type="text" name="group" id="<%= $g %>" class="form-control" placeholder="<%= ucfirst $g %> parameter1, param2, etc.">
+  <input type="text" name="group" id="<%= $g %>" class="form-control" placeholder="<%= $g %> parameter1, param2, etc.">
   <p></p>
 %   }
   <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Add parameters</button>
@@ -420,7 +420,7 @@ __DATA__
   <input type="hidden" name="model" value="<%= $model %>">
   <input type="hidden" name="groups" value="<%= $groups %>">
 % for my $g (@$group_list) {
-  <label for="<%= $g %>_param"><%= ucfirst $g %>:</label>
+  <label for="<%= $g %>_param"><%= $g %>:</label>
   <input type="text" name="group" id="<%= $g %>_param" value="<%= join ',', $specs->{$g}->@* %>" class="form-control" placeholder="<%= ucfirst $g %> parameter1, param2, etc.">
   <p></p>
 % }
@@ -477,7 +477,7 @@ __DATA__
 %   my @things = $key eq 'parameter' ? ($selected->{parameter}) : $key eq 'param_to' ? ($selected->{param_to}) : $specs->{$my_key}->@*;
 %     for my $i (@things) {
 %       next if !defined($i) || $i eq 'none' || $i eq '';
-      <option value="<%= $i %>" <%= $selected->{$key} && $i eq $selected->{$key} ? 'selected' : '' %>><%= ucfirst $i %></option>
+      <option value="<%= $i %>" <%= defined $selected->{$key} && $i eq $selected->{$key} ? 'selected' : '' %>><%= ucfirst $i %></option>
 %     }
     </select>
 %   }
