@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0028';
+our $VERSION = '0.0029';
 
 use Moo;
 use strictures 2;
@@ -71,7 +71,7 @@ sub make_setting {
       { id => $id },
     )->expand(json => 'settings')->hash->{settings};
     for my $arg (keys %args) {
-      delete $args{$arg} if $args{$arg} eq '' && !exists $result->{$arg};
+      $args{$arg} = '' unless defined $args{$arg};
     }
     my $params = { %$result, %args };
     $self->_sqlite->update(
@@ -221,7 +221,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0028
+version 0.0029
 
 =head1 SYNOPSIS
 
